@@ -1,6 +1,6 @@
 package Elasticsearch::Role::API;
 {
-  $Elasticsearch::Role::API::VERSION = '0.75';
+  $Elasticsearch::Role::API::VERSION = '0.76';
 }
 
 use Moo::Role;
@@ -32,7 +32,7 @@ sub api {
         method    => 'POST',
         path      => '{index-when-type}/{type|blank}/_bulk',
         serialize => 'bulk',
-        qs        => [ 'consistency', 'refresh', 'replication', 'type' ],
+        qs => [ 'consistency', 'refresh', 'replication', 'timeout', 'type' ],
     },
 
     'clear_scroll' => {
@@ -270,12 +270,12 @@ sub api {
     },
 
     'cluster.get_settings' => {
-        doc  => 'cluster-update-settings/',
+        doc  => 'cluster-update-settings',
         path => '_cluster/settings',
     },
 
     'cluster.health' => {
-        doc  => 'cluster-health/',
+        doc  => 'cluster-health',
         path => '_cluster/health',
         qs   => [
             'level',                      'local',
@@ -286,13 +286,13 @@ sub api {
     },
 
     'cluster.hot_threads' => {
-        doc  => 'cluster-nodes-hot-threads/',
+        doc  => 'cluster-nodes-hot-threads',
         path => '_nodes/{nodes|blank}/hot_threads',
         qs   => [ 'interval', 'snapshots', 'threads', 'type' ],
     },
 
     'cluster.node_info' => {
-        doc  => 'cluster-nodes-info/',
+        doc  => 'cluster-nodes-info',
         path => '_nodes/{nodes|blank}',
         qs   => [
             'all',      'clear',   'http',        'jvm',
@@ -302,14 +302,14 @@ sub api {
     },
 
     'cluster.shutdown' => {
-        doc    => 'cluster-nodes-shutdown/',
+        doc    => 'cluster-nodes-shutdown',
         method => 'POST',
         path   => '_cluster/nodes/{nodes|blank}/_shutdown',
         qs     => [ 'delay', 'exit' ],
     },
 
     'cluster.node_stats' => {
-        doc  => 'cluster-nodes-stats/',
+        doc  => 'cluster-nodes-stats',
         path => '_nodes/{nodes|blank}/stats/{metric|blank}',
         qs   => [
             'all',  'clear',   'fields',      'fs',
@@ -323,7 +323,7 @@ sub api {
             desc => 'The settings to be updated. Can be either '
                 . '`transient` or `persistent`.'
         },
-        doc    => 'cluster-update-settings/',
+        doc    => 'cluster-update-settings',
         method => 'PUT',
         path   => '_cluster/settings',
     },
@@ -333,14 +333,14 @@ sub api {
             desc => 'The definition of `commands` to perform '
                 . '(`move`, `cancel`, `allocate`)'
         },
-        doc    => 'cluster-reroute/',
+        doc    => 'cluster-reroute',
         method => 'POST',
         path   => '_cluster/reroute',
         qs     => [ 'dry_run', 'filter_metadata' ],
     },
 
     'cluster.state' => {
-        doc  => 'cluster-state/',
+        doc  => 'cluster-state',
         path => '_cluster/state',
         qs   => [
             'filter_blocks',  'filter_index_templates',
@@ -353,7 +353,7 @@ sub api {
     'indices.analyze' => {
         body =>
             { desc => 'The text on which the analysis should be performed' },
-        doc    => 'indices-analyze/',
+        doc    => 'indices-analyze',
         method => 'POST',
         path   => '{index|blank}/_analyze',
         qs     => [
@@ -363,7 +363,7 @@ sub api {
     },
 
     'indices.clear_cache' => {
-        doc    => 'indices-clearcache/',
+        doc    => 'indices-clearcache',
         method => 'POST',
         path   => '{indices}/_cache/clear',
         qs     => [
@@ -376,7 +376,7 @@ sub api {
     },
 
     'indices.close' => {
-        doc    => 'indices-open-close/',
+        doc    => 'indices-open-close',
         method => 'POST',
         path   => '{req_indices}/_close',
         qs     => [ 'timeout', 'master_timeout' ],
@@ -387,115 +387,121 @@ sub api {
             desc => 'The configuration for the index '
                 . '(`settings` and `mappings`)'
         },
-        doc    => 'indices-create-index/',
+        doc    => 'indices-create-index',
         method => 'PUT',
         path   => '{index}',
         qs     => [ 'timeout', 'master_timeout' ],
     },
 
     'indices.delete' => {
-        doc    => 'indices-delete-index/',
+        doc    => 'indices-delete-index',
         method => 'DELETE',
         path   => '{req_indices}',
         qs     => [ 'timeout', 'master_timeout' ],
     },
 
     'indices.delete_alias' => {
-        doc    => 'indices-aliases/',
+        doc    => 'indices-aliases',
         method => 'DELETE',
         path   => '{index}/_alias/{name}',
         qs     => [ 'timeout', 'master_timeout' ],
     },
 
     'indices.delete_mapping' => {
-        doc    => 'indices-delete-mapping/',
+        doc    => 'indices-delete-mapping',
         method => 'DELETE',
         path   => '{req_indices}/{type}',
         qs     => ['master_timeout'],
     },
 
     'indices.delete_template' => {
-        doc    => 'indices-templates/',
+        doc    => 'indices-templates',
         method => 'DELETE',
         path   => '_template/{name}',
         qs     => [ 'timeout', 'master_timeout' ],
     },
 
     'indices.delete_warmer' => {
-        doc    => 'indices-warmers/',
+        doc    => 'indices-warmers',
         method => 'DELETE',
         path   => '{req_indices}/_warmer/{names}',
         qs     => ['master_timeout'],
     },
 
     'indices.exists' => {
-        doc    => 'indices-exists/',
+        doc    => 'indices-exists',
         method => 'HEAD',
         path   => '{req_indices}',
     },
 
     'indices.exists_alias' => {
-        doc    => 'indices-aliases/',
+        doc    => 'indices-aliases',
         method => 'HEAD',
         path   => '{indices}/_alias/{names}',
         qs     => ['ignore_indices'],
     },
 
     'indices.exists_type' => {
-        doc    => 'indices-types-exists/',
+        doc    => 'indices-types-exists',
         method => 'HEAD',
         path   => '{indices|all}/{req_types}',
         qs     => ['ignore_indices'],
     },
 
     'indices.flush' => {
-        doc    => 'indices-flush/',
+        doc    => 'indices-flush',
         method => 'POST',
         path   => '{indices}/_flush',
         qs     => [ 'force', 'full', 'ignore_indices', 'refresh' ],
     },
 
     'indices.get_alias' => {
-        doc  => 'indices-aliases/',
+        doc  => 'indices-aliases',
         path => '{indices}/_alias/{names}',
         qs   => ['ignore_indices'],
     },
 
     'indices.get_aliases' => {
-        doc  => 'indices-aliases/',
+        doc  => 'indices-aliases',
         path => '{indices}/_aliases',
         qs   => ['timeout'],
     },
 
+    'indices.get_field_mapping' => {
+        doc  => 'indices-get-field-mapping',
+        path => '{indices|all-type}/{types}/_mapping/field/{field}',
+        qs   => ['include_defaults'],
+    },
+
     'indices.get_mapping' => {
-        doc  => 'indices-get-mapping/',
+        doc  => 'indices-get-mapping',
         path => '{indices|all-type}/{types}/_mapping',
     },
 
     'indices.get_settings' => {
-        doc  => 'indices-get-settings/',
+        doc  => 'indices-get-settings',
         path => '{indices}/_settings',
     },
 
     'indices.get_template' => {
-        doc  => 'indices-templates/',
+        doc  => 'indices-templates',
         path => '_template/{name|blank}',
     },
 
     'indices.get_warmer' => {
-        doc  => 'indices-warmers/',
+        doc  => 'indices-warmers',
         path => '{indices|all}/_warmer/{names}',
     },
 
     'indices.open' => {
-        doc    => 'indices-open-close/',
+        doc    => 'indices-open-close',
         method => 'POST',
         path   => '{indices|all}/_open',
         qs     => [ 'timeout', 'master_timeout' ],
     },
 
     'indices.optimize' => {
-        doc    => 'indices-optimize/',
+        doc    => 'indices-optimize',
         method => 'POST',
         path   => '{indices}/_optimize',
         qs     => [
@@ -510,7 +516,7 @@ sub api {
             desc => 'The settings for the alias, '
                 . 'such as `routing` or `filter`',
         },
-        doc    => 'indices-aliases/',
+        doc    => 'indices-aliases',
         method => 'PUT',
         path   => '{index}/_alias/{name}',
         qs     => [ 'timeout', 'master_timeout' ],
@@ -521,7 +527,7 @@ sub api {
             desc     => 'The mapping definition',
             required => 1
         },
-        doc    => 'indices-put-mapping/',
+        doc    => 'indices-put-mapping',
         method => 'PUT',
         path   => '{indices|all}/{type}/_mapping',
         qs     => [ 'ignore_conflicts', 'timeout', 'master_timeout' ],
@@ -532,7 +538,7 @@ sub api {
             desc     => 'The index settings to be updated',
             required => 1
         },
-        doc    => 'indices-update-settings/',
+        doc    => 'indices-update-settings',
         method => 'PUT',
         path   => '{indices}/_settings',
         qs     => ['master_timeout'],
@@ -543,7 +549,7 @@ sub api {
             desc     => 'The template definition',
             required => 1
         },
-        doc    => 'indices-templates/',
+        doc    => 'indices-templates',
         method => 'PUT',
         path   => '_template/{name}',
         qs     => [ 'order', 'timeout', 'master_timeout' ],
@@ -555,34 +561,34 @@ sub api {
                 . ' the warmer (query, filters, facets, sorting, etc)',
             required => 1
         },
-        doc    => 'indices-warmers/',
+        doc    => 'indices-warmers',
         method => 'PUT',
         path   => '{indices|all}/_warmer/{name}',
         qs     => ['master_timeout'],
     },
 
     'indices.refresh' => {
-        doc    => 'indices-refresh/',
+        doc    => 'indices-refresh',
         method => 'POST',
         path   => '{indices}/_refresh',
         qs     => ['ignore_indices'],
     },
 
     'indices.segments' => {
-        doc  => 'indices-segments/',
+        doc  => 'indices-segments',
         path => '{indices}/_segments',
         qs   => [ 'ignore_indices', ],
     },
 
     'indices.snapshot_index' => {
-        docs   => 'indices-gateway-snapshot/',
+        docs   => 'indices-gateway-snapshot',
         method => 'POST',
         path   => '{indices}/_gateway/snapshot',
         params => ['ignore_indices']
     },
 
     'indices.stats' => {
-        doc  => 'indices-stats/',
+        doc  => 'indices-stats',
         path => '{indices}/_stats',
         qs   => [
             'all',              'clear',
@@ -599,7 +605,7 @@ sub api {
     },
 
     'indices.status' => {
-        doc  => 'indices-status/',
+        doc  => 'indices-status',
         path => '{indices}/_status',
         qs   => [ 'ignore_indices', 'recovery', 'snapshot' ],
     },
@@ -609,7 +615,7 @@ sub api {
             required => 1,
             desc     => 'The definition of `actions` to perform'
         },
-        doc    => 'indices-aliases/',
+        doc    => 'indices-aliases',
         method => 'POST',
         path   => '_aliases',
         qs     => [ 'timeout', 'master_timeout' ],
@@ -617,7 +623,7 @@ sub api {
 
     'indices.validate_query' => {
         body => { desc => 'The query definition' },
-        doc  => 'search-validate/',
+        doc  => 'search-validate',
         path => '{indices|all-type}/{types}/_validate/query',
         qs   => [ 'explain', 'ignore_indices', 'q', 'source' ],
     },
@@ -639,7 +645,7 @@ Elasticsearch::Role::API - This class contains the spec for the Elasticsearch AP
 
 =head1 VERSION
 
-version 0.75
+version 0.76
 
 =head1 DESCRIPTION
 
